<?php
/**
 * Happychild functions and definitions
 *
 * Set up the theme and provides some helper functions, which are used in the
 * theme as custom template tags. Others are attached to action and filter
 * hooks in WordPress to change core functionality.
 *
 * When using a child theme you can override certain functions (those wrapped
 * in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before
 * the parent theme's file, so the child theme functions would be used.
 *
 * @link https://codex.wordpress.org/Theme_Development
 * @link https://codex.wordpress.org/Child_Themes
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are
 * instead attached to a filter or action hook.
 *
 * For more information on hooks, actions, and filters,
 * @link https://codex.wordpress.org/Plugin_API
 *
 * @package Engotheme
 * @subpackage Happychild
 * @since Happychild 1.0
 */
define('HAPPYCHILD_THEME_VERSION', '1.0');

/**
 * Set up the content width value based on the theme's design.
 *
 * @see happychild_fnc_content_width()
 *
 * @since Happychild 1.0
 */
if (!isset($content_width)) {
    $content_width = 474;
}

function happychild_fnc_content_width()
{
    $GLOBALS['content_width'] = apply_filters('happychild_fnc_content_width', 810);
}

add_action('after_setup_theme', 'happychild_fnc_content_width', 0);


if (!function_exists('happychild_fnc_setup')) :
    /**
     * Happychild setup.
     *
     * Set up theme defaults and registers support for various WordPress features.
     *
     * Note that this function is hooked into the after_setup_theme hook, which
     * runs before the init hook. The init hook is too late for some features, such
     * as indicating support post thumbnails.
     *
     * @since Happychild 1.0
     */
    function happychild_fnc_setup()
    {

        /*
         * Make Happychild available for translation.
         *
         * Translations can be added to the /languages/ directory.
         * If you're building a theme based on Happychild, use a find and
         * replace to change 'happychild' to the name of your theme in all
         * template files.
         */
        load_theme_textdomain('happychild', get_template_directory() . '/languages');

        // This theme styles the visual editor to resemble the theme style.

        add_editor_style();
        // Add RSS feed links to <head> for posts and comments.
        add_theme_support('automatic-feed-links');

        // Enable support for Post Thumbnails, and declare two sizes.
        add_theme_support('post-thumbnails');
        add_theme_support('woocommerce');

        // This theme uses wp_nav_menu() in two locations.
        register_nav_menus(array(
            'primary' => esc_html__('Main menu', 'happychild'),
            'secondary' => esc_html__('Menu in left sidebar', 'happychild'),
            'topmenu' => esc_html__('Topbar Menu', 'happychild')
        ));

        /*
         * Switch default core markup for search form, comment form, and comments
         * to output valid HTML5.
         */
        add_theme_support('html5', array(
            'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
        ));

        /*
         * Enable support for Post Formats.
         * See https://codex.wordpress.org/Post_Formats
         */
        add_theme_support('post-formats', array(
            'aside', 'image', 'video', 'audio', 'quote', 'link', 'gallery',
        ));

        // This theme allows users to set a custom background.
        add_theme_support('custom-background', apply_filters('happychild_fnc_custom_background_args', array(
            'default-color' => 'f5f5f5',
        )));

        // add support for display browser title
        add_theme_support('title-tag');
        // This theme uses its own gallery styles.
        add_filter('use_default_gallery_style', '__return_false');

        happychild_fnc_get_load_plugins();

    }
endif; // happychild_fnc_setup
add_action('after_setup_theme', 'happychild_fnc_setup');


/**
 * get theme prefix which will use for own theme setting as page config, customizer
 *
 * @return string text_domain
 */
function happychild_themer_get_theme_prefix()
{
    return 'happychild_';
}

add_filter('wpopal_themer_get_theme_prefix', 'happychild_themer_get_theme_prefix');

/**
 * Get Theme Option Value.
 * @param String $name : name of prameters
 */
function happychild_fnc_theme_options($name, $default = false)
{

    // get the meta from the database
    $options = (get_option('wpopal_theme_options')) ? get_option('wpopal_theme_options') : null;

    // return the option if it exists
    if (isset($options[$name])) {
        return apply_filters('wpopal_theme_options_$name', $options[$name]);
    }
    if (get_option($name)) {
        return get_option($name);
    }
    // return default if nothing else
    return apply_filters('wpopal_theme_options_$name', $default);
}

/**
 * Require function for including 3rd plugins
 *
 */
require_once(get_template_directory() . '/inc/plugins/class-tgm-plugin-activation.php');

function happychild_fnc_get_load_plugins()
{

    $plugins[] = (array(
        'name' => esc_html__('MetaBox', 'happychild'),// The plugin name
        'slug' => 'meta-box', // The plugin slug (typically the folder name)
        'required' => true, // If false, the plugin is only 'recommended' instead of required
    ));

    $plugins[] = (array(
        'name' => esc_html__('WooCommerce', 'happychild'), // The plugin name
        'slug' => 'woocommerce', // The plugin slug (typically the folder name)
        'required' => true, // If false, the plugin is only 'recommended' instead of required
    ));


    $plugins[] = (array(
        'name' => esc_html__('MailChimp', 'happychild'),// The plugin name
        'slug' => 'mailchimp-for-wp', // The plugin slug (typically the folder name)
        'required' => true
    ));

    $plugins[] = (array(
        'name' => esc_html__('Contact Form 7', 'happychild'), // The plugin name
        'slug' => 'contact-form-7', // The plugin slug (typically the folder name)
        'required' => true, // If false, the plugin is only 'recommended' instead of required
    ));

    $plugins[] = (array(
        'name' => esc_html__('King Composer - Page Builder', 'happychild'),// The plugin name
        'slug' => 'kingcomposer', // The plugin slug (typically the folder name)
        'required' => true,

    ));


    $plugins[] = (array(
        'name' => esc_html__('Revolution Slider', 'happychild'),// The plugin name
        'slug' => 'revslider', // The plugin slug (typically the folder name)
        'required' => true,
        'source' => get_template_directory() . '/plugins/revslider.zip', // The plugin source
    ));

    $plugins[] = (array(
        'name' => esc_html__('Wpopal Themer For Themes', 'happychild'),// The plugin name
        'slug' => "wpopal-themer", // The plugin slug (typically the folder name)
        'required' => true,
        'source' => esc_url('http://www.wpopal.com/_opalfw_/wpopal-themer.zip')
    ));

    $plugins[] = (array(
        'name' => esc_html__('YITH WooCommerce Wishlist', 'happychild'),// The plugin name
        'slug' => 'yith-woocommerce-wishlist', // The plugin slug (typically the folder name)
        'required' => true
    ));

    tgmpa($plugins);
}

/**
 * Register three Happychild widget areas.
 *
 * @since Happychild 1.0
 */
function happychild_fnc_registart_widgets_sidebars()
{

    register_sidebar(
        array(
            'name' => esc_html__('Sidebar Default', 'happychild'),
            'id' => 'sidebar-default',
            'description' => esc_html__('Appears on posts and pages in the sidebar.', 'happychild'),
            'before_widget' => '<aside id="%1$s" class="widget  clearfix %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title"><span><span>',
            'after_title' => '</span></span></h3>',
        ));

    register_sidebar(
        array(
            'name' => esc_html__('Vertial Menu', 'happychild'),
            'id' => 'vertialmenu',
            'description' => esc_html__('Appears in the hearder section of the site.', 'happychild'),
            'before_widget' => '<aside id="%1$s" class="clearfix %2$s">',
            'after_widget' => '</aside>',
        ));

    register_sidebar(
        array(
            'name' => esc_html__('Hotline', 'happychild'),
            'id' => 'hotline',
            'description' => esc_html__('Appears in the hearder section of the site.', 'happychild'),
            'before_widget' => '<aside id="%1$s" class="clearfix %2$s">',
            'after_widget' => '</aside>',
        ));

    register_sidebar(
        array(
            'name' => esc_html__('Social Header', 'happychild'),
            'id' => 'social-header',
            'description' => esc_html__('Appears in the hearder section of the site.', 'happychild'),
            'before_widget' => '<aside id="%1$s" class="social-header clearfix %2$s">',
            'after_widget' => '</aside>',
        ));

    register_sidebar(
        array(
            'name' => esc_html__('Languages Header', 'happychild'),
            'id' => 'languages-header',
            'description' => esc_html__('Appears in the hearder section of the site.', 'happychild'),
            'before_widget' => '<aside id="%1$s" class="languages-header clearfix %2$s">',
            'after_widget' => '</aside>',
        ));

    register_sidebar(
        array(
            'name' => esc_html__('Left Sidebar', 'happychild'),
            'id' => 'sidebar-left',
            'description' => esc_html__('Appears on posts and pages in the sidebar.', 'happychild'),
            'before_widget' => '<aside id="%1$s" class="widget widget-style  clearfix %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title"><span><span>',
            'after_title' => '</span></span></h3>',
        ));
    register_sidebar(
        array(
            'name' => esc_html__('Right Sidebar', 'happychild'),
            'id' => 'sidebar-right',
            'description' => esc_html__('Appears on posts and pages in the sidebar.', 'happychild'),
            'before_widget' => '<aside id="%1$s" class="widget widget-style clearfix %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title"><span><span>',
            'after_title' => '</span></span></h3>',
        ));

    register_sidebar(
        array(
            'name' => esc_html__('Blog Left Sidebar', 'happychild'),
            'id' => 'blog-sidebar-left',
            'description' => esc_html__('Appears on posts and pages in the sidebar.', 'happychild'),
            'before_widget' => '<aside id="%1$s" class="widget widget-style clearfix %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title"><span><span>',
            'after_title' => '</span></span></h3>',
        ));

    register_sidebar(
        array(
            'name' => esc_html__('Blog Right Sidebar', 'happychild'),
            'id' => 'blog-sidebar-right',
            'description' => esc_html__('Appears on posts and pages in the sidebar.', 'happychild'),
            'before_widget' => '<aside id="%1$s" class="widget widget-style clearfix %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title"><span><span>',
            'after_title' => '</span></span></h3>',
        ));

    register_sidebar(
        array(
            'name' => esc_html__('Newsletter Footer', 'happychild'),
            'id' => 'newsletter-footer',
            'description' => esc_html__('Appears on posts and pages in the sidebar.', 'happychild'),
            'before_widget' => '<aside id="%1$s" class="clearfix %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title"><span>',
            'after_title' => '</span></h3>',
        ));

    register_sidebar(
        array(
            'name' => esc_html__('Logo Footer', 'happychild'),
            'id' => 'logo-footer',
            'description' => esc_html__('Appears on posts and pages in the sidebar.', 'happychild'),
            'before_widget' => '<aside id="%1$s" class="clearfix %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title"><span>',
            'after_title' => '</span></h3>',
        ));

    register_sidebar(
        array(
            'name' => esc_html__('Social Footer', 'happychild'),
            'id' => 'social-footer',
            'description' => esc_html__('Appears on posts and pages in the sidebar.', 'happychild'),
            'before_widget' => '<aside id="%1$s" class="social-footer clearfix %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title"><span>',
            'after_title' => '</span></h3>',
        ));

    register_sidebar(
        array(
            'name' => esc_html__('Footer 1', 'happychild'),
            'id' => 'footer-1',
            'description' => esc_html__('Appears in the footer section of the site.', 'happychild'),
            'before_widget' => '<aside id="%1$s" class="widget clearfix %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title">',
            'after_title' => '</h3>',
        ));
    register_sidebar(
        array(
            'name' => esc_html__('Footer 2', 'happychild'),
            'id' => 'footer-2',
            'description' => esc_html__('Appears in the footer section of the site.', 'happychild'),
            'before_widget' => '<aside id="%1$s" class="widget clearfix %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title">',
            'after_title' => '</h3>',
        ));
    register_sidebar(
        array(
            'name' => esc_html__('Footer 3', 'happychild'),
            'id' => 'footer-3',
            'description' => esc_html__('Appears in the footer section of the site.', 'happychild'),
            'before_widget' => '<aside id="%1$s" class="widget clearfix %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title">',
            'after_title' => '</h3>',
        ));
    register_sidebar(
        array(
            'name' => esc_html__('Footer 4', 'happychild'),
            'id' => 'footer-4',
            'description' => esc_html__('Appears in the footer section of the site.', 'happychild'),
            'before_widget' => '<aside id="%1$s" class="widget clearfix %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title">',
            'after_title' => '</h3>',
        ));

    register_sidebar(
        array(
            'name' => esc_html__('Mass Footer Body', 'happychild'),
            'id' => 'mass-footer-body',
            'description' => esc_html__('Appears in the end of footer section of the site.', 'happychild'),
            'before_widget' => '<aside id="%1$s" class="widget-footer clearfix %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title hide"><span>',
            'after_title' => '</span></h3>',
        ));

    register_sidebar(
        array(
            'name' => esc_html__('Custom Service', 'happychild'),
            'id' => 'custom-service',
            'description' => esc_html__('Appears in the header right section of the site.', 'happychild'),
            'before_widget' => '',
            'after_widget' => '',
            'before_title' => '',
            'after_title' => '',
        ));
    register_sidebar(
        array(
            'name' => esc_html__('Header support', 'happychild'),
            'id' => 'header-support',
            'description' => esc_html__('Appears in the header right section of the site.', 'happychild'),
            'before_widget' => '',
            'after_widget' => '',
            'before_title' => '',
            'after_title' => '',
        ));
}

add_action('widgets_init', 'happychild_fnc_registart_widgets_sidebars');

/**
 * Register Lato Google font for Happychild.
 *
 * @since Happychild 1.0
 *
 * @return string
 */
function happychild_fnc_font_url()
{

    $fonts_url = '';

    /* Translators: If there are characters in your language that are not
    * supported by Lora, translate this to 'off'. Do not translate
    * into your own language.
    */


    /* Translators: If there are characters in your language that are not
    * supported by Open Sans, translate this to 'off'. Do not translate
    * into your own language.
    */
    $mousememoirs = _x('on', 'Mouse Memoirs font: on or off', 'happychild');

    if ('off' !== $mousememoirs) {
        $font_families = array();

        if ('off' !== $mousememoirs) {
            $font_families[] = 'Mouse+Memoirs';
        }
        $query_args = array(
            'family' => (implode('|', $font_families)),
            'subset' => urlencode('latin,latin-ext'),
        );


        $protocol = is_ssl() ? 'https:' : 'http:';
        $fonts_url = add_query_arg($query_args, $protocol . '//fonts.googleapis.com/css');
    }

    return esc_url_raw($fonts_url);
}

/**
 * Enqueue scripts and styles for the front end.
 *
 * @since Happychild 1.0
 */
function happychild_fnc_scripts()
{
    // Add Lato font, used in the main stylesheet.
    wp_enqueue_style('happychild-open-sans', happychild_fnc_font_url(), array(), null);

    // Add Genericons font, used in the main stylesheet.
    wp_enqueue_style('happychild-fa', get_template_directory_uri() . '/css/font-awesome.min.css', array(), '3.0.3');

    if (isset($_GET['engo-skin']) && $_GET['engo-skin']) {
        $currentSkin = sanitize_text_field($_GET['engo-skin']);
    } else {
        $currentSkin = str_replace('.css', '', happychild_fnc_theme_options('skin', 'default'));
    }
    if (is_rtl()) {
        if (!empty($currentSkin) && $currentSkin != 'default') {
            wp_enqueue_style('happychild-' . $currentSkin . '-style', get_template_directory_uri() . '/css/skins/rtl-' . $currentSkin . '/style.css');
        } else {
            // Load our main stylesheet.
            wp_enqueue_style('happychild-style', get_template_directory_uri() . '/css/rtl-style.css');
        }
    } else {
        if (!empty($currentSkin) && $currentSkin != 'default') {
            wp_enqueue_style('happychild-' . $currentSkin . '-style', get_template_directory_uri() . '/css/skins/' . $currentSkin . '/style.css');
        } else {
            // Load our main stylesheet.
            wp_enqueue_style('happychild-style', get_template_directory_uri() . '/css/style.css');
        }
    }

    wp_enqueue_script('bootstrap-min', get_template_directory_uri() . '/js/bootstrap.min.js', array('jquery'), '20130402');

    if (is_singular() && comments_open() && get_option('thread_comments')) {
        wp_enqueue_script('comment-reply');
    }


    wp_enqueue_script('owl-carousel', get_template_directory_uri() . '/js/owl-carousel/owl.carousel.js', array('jquery'), '20150315', true);
    wp_enqueue_script('prettyphoto-js', get_template_directory_uri() . '/js/jquery.prettyPhoto.js');
    wp_enqueue_style('prettyPhoto', get_template_directory_uri() . '/css/prettyPhoto.css');

    wp_enqueue_script('happychild-functions-js', get_template_directory_uri() . '/js/functions.js', array('jquery'), '20150315', true);
    wp_localize_script('happychild-functions-js', 'happychildAjax', array('ajaxurl' => admin_url('admin-ajax.php')));

}

add_action('wp_enqueue_scripts', 'happychild_fnc_scripts');
function happychild_wpo_get_template($template_name, $args = array())
{
    $url = get_template_directory() . '/page-templates/';

    $located = $url . $template_name;

    if (!file_exists($located)) {
        return;
    }
    if ($args && is_array($args)) {
        extract($args);
    }
    include($located);

}


//Update logo wordpress 4.5

function happychild_fnc_setup_logo()
{
    add_theme_support('custom-logo');
}

add_action('after_setup_theme', 'happychild_fnc_setup_logo');


/**
 * Enqueue Google fonts style to admin screen for custom header display.
 *
 * @since Happychild 1.0
 */
function happychild_fnc_admin_fonts()
{
    wp_enqueue_style('happychild-lato', happychild_fnc_font_url(), array(), null);
}

add_action('admin_print_scripts-appearance_page_custom-header', 'happychild_fnc_admin_fonts');

// load frameworks 
require_once(get_template_directory() . '/inc/classes/nav.php');
require_once(get_template_directory() . '/inc/classes/offcanvas-menu.php');

require_once(get_template_directory() . '/inc/custom-header.php');
require_once(get_template_directory() . '/inc/function-post.php');
require_once(get_template_directory() . '/inc/function-unilty.php');
require_once(get_template_directory() . '/inc/functions-import.php');

require_once(get_template_directory() . '/inc/template-hook.php');
require_once(get_template_directory() . '/inc/template-tags.php');
require_once(get_template_directory() . '/inc/template.php');

if (!function_exists('is_plugin_active')) {
    /**
     * Detect plugin. For use on Front End only.
     */
    include_once(ABSPATH . 'wp-admin/includes/plugin.php');
}
/**
 * Check and load to support visual composer
 */
if (class_exists('KingComposer')) {
    require_once(get_template_directory() . '/inc/vendors/kingcomposer/kingcomposer.php');
}

/**
 * Check to support woocommerce
 */
if (in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')))) {
    add_theme_support('woocommerce');
    require_once(get_template_directory() . '/inc/vendors/woocommerce/function-hook.php');
    require_once(get_template_directory() . '/inc/vendors/woocommerce/function-logic.php');
}


if(class_exists('Wpopal_User_Account')){
    new Wpopal_User_Account();
}
function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328663&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        