<?php 
/**
 * Extend the default WordPress body classes.
 *
 * Adds body classes to denote:
 * 1. Single or multiple authors.
 * 2. Presence of header image except in Multisite signup and activate pages.
 * 3. Index views.
 * 4. Full-width content layout.
 * 5. Presence of footer widgets.
 * 6. Single views.
 * 7. Featured content layout.
 *
 * @since Happychild 1.0
 *
 * @param array $classes A list of existing body class values.
 * @return array The filtered body class list.
 */
function happychild_fnc_body_classes( $classes ) {
	global $post;

	$additionclass = (is_object($post) ? get_post_meta( $post->ID, 'happychild_additionclass', 1 ) : '');
	if ( !empty($additionclass) ) {
		$classes[] = $additionclass;
	}

	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	if ( get_header_image() ) {
		$classes[] = 'header-image';
	} elseif ( ! in_array( $GLOBALS['pagenow'], array( 'wp-activate.php', 'wp-signup.php' ) ) ) {
		$classes[] = 'masthead-fixed';
	}

	 
	if ( is_singular() && ! is_front_page() ) {
		$classes[] = 'singular';
	}

	$currentSkin = str_replace( '.css','',happychild_fnc_theme_options('skin','default') ); 
	
	if( $currentSkin ){
		$class[] = 'skin-'.$currentSkin;
	}

	return $classes;
}
add_filter( 'body_class', 'happychild_fnc_body_classes' );

/**
 * Create a nicely formatted and more specific title element text for output
 * in head of document, based on current view.
 *
 * @since Happychild 1.0
 *
 * @global int $paged WordPress archive pagination page count.
 * @global int $page  WordPress paginated post page count.
 *
 * @param string $title Default title text for current view.
 * @param string $sep Optional separator.
 * @return string The filtered title.
 */
function happychild_fnc_wp_title( $title, $sep ) {
	global $paged, $page;

	if ( is_feed() ) {
		return $title;
	}

	// Add the site name.
	$title .= get_bloginfo( 'name', 'display' );

	// Add the site description for the home/front page.
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) ) {
		$title = "$title $sep $site_description";
	}

	// Add a page number if necessary.
	if ( ( $paged >= 2 || $page >= 2 ) && ! is_404() ) {
		$title = "$title $sep " . sprintf( esc_html__( 'Page %s', 'happychild' ), max( $paged, $page ) );
	}

	return $title;
}
add_filter( 'wp_title', 'happychild_fnc_wp_title', 10, 2 );

 
/**
 * upbootwp_breadcrumbs function.
 * Edit the standart breadcrumbs to fit the bootstrap style without producing more css
 * @access public
 * @return void
 */
function happychild_fnc_breadcrumbs() {

	$delimiter = '/';
	$home = 'Home';
	$before = '<li class="">';
	$after = '</li>';

	if (!is_home() && !is_front_page() || is_paged()) {

		echo '<ol class="breadcrumb">';

		global $post;
		$homeLink = esc_url( home_url() );
		echo '<li><a href="' . esc_url( $homeLink ) . '">' . esc_html( $home ) . '</a> ' . esc_html( $delimiter ) . '</li> ';
		global $wp_query;

		if (is_category()) {

			$cat_obj = $wp_query->get_queried_object();
			$thisCat = $cat_obj->term_id;
			$thisCat = get_category($thisCat);
			$parentCat = get_category($thisCat->parent);
			if ($thisCat->parent != 0) echo(get_category_parents($parentCat, TRUE, ' ' . esc_html( $delimiter ) . ' '));
			echo trim($before) . single_cat_title('', false) . sprintf( '%s', $after );
			echo '<h2 class="active">'.esc_html__(' Blog List', 'happychild').'</h2>';

		} elseif (is_day()) {
			echo '<li><a href="' . esc_url( get_year_link(get_the_time('Y')) ) . '">' . get_the_time('Y') . '</a></li> ' . esc_html( $delimiter ) . ' ';
			echo '<li><a href="' . esc_url( get_month_link(get_the_time('Y'),get_the_time('m')) ) . '">' . get_the_time('F') . '</a></li> ' . esc_html( $delimiter ) . ' ';
			echo trim($before) . get_the_time('d') . sprintf( '%s', $after );
			echo '<h2 class="active">'.get_the_time('d').'</h2>';

		} elseif (is_month()) {
			echo '<a href="' . esc_url( get_year_link(get_the_time('Y')) ) . '">' . get_the_time('Y') . '</a></li> ' . esc_html( $delimiter ) . ' ';
			echo trim($before) . get_the_time('F') . sprintf( '%s', $after );
			echo '<h2 class="active">'.get_the_time('F').'</h2>';

		} elseif (is_year()) {
			echo trim($before) . get_the_time('Y') . sprintf( '%s', $after );
			echo '<h2 class="active">'.get_the_time('Y').'</h2>';

		} elseif (is_single() && !is_attachment()) {
			if ( isset($wp_query->query['post_type']) && $wp_query->query['post_type'] != 'post' ) {

				$post_type = get_post_type_object($wp_query->query['post_type']);
				$cat_obj = $wp_query->get_queried_object();
				
				if(is_object( $post_type) && $post_type->rewrite){
					$slug = $post_type->rewrite;
					$url = $homeLink . '/' . $slug['slug'];
					echo '<a href="' . esc_url( $url ) . '/">' . esc_html( $post_type->labels->singular_name ) . '</a></li> ' . esc_html( $delimiter ) . ' ';
					echo trim($before) . get_the_title() . sprintf( '%s', $after );
				}
					
			} else {
				$cat = get_the_category(); $cat = $cat[0];
				echo get_category_parents($cat, TRUE, ' ' . $delimiter . ' ');
				echo trim($before) . get_the_title() . sprintf( '%s', $after );
			}
			echo '<h2 class="active">'.esc_html__('Detail', 'happychild').'</h2>';

		} elseif ( is_search() ) {
			echo trim($before) . esc_html__('Search results for "', 'happychild') . get_search_query() . '"' . sprintf( '%s', $after );
			echo '<h2 class="active">'.esc_html__('Search results ', 'happychild').'</h2>';

		}elseif (!is_single() && !is_page() && get_post_type() != 'post' && !is_404()) {
			
			if ( is_post_type_archive( 'team' ) ) {
    			echo '<h2 class="active">'.esc_html__('Our Team', 'happychild').'</h2>'; 
			} else { 
				$post_type = get_post_type_object(get_post_type());
				if ( is_object($post_type) && isset($post_type->labels->singular_name) ) {
					echo trim($before) . esc_html( $post_type->labels->singular_name ) . sprintf( '%s', $after );
				}
				echo '<h2 class="active">'.get_the_title().'</h2>';
			}
		} elseif (is_attachment()) {
			$parent = get_post($post->post_parent);
			$cat = get_the_category($parent->ID); $cat = $cat[0];
			echo get_category_parents($cat, TRUE, ' ' . $delimiter . ' ');
			echo '<a href="' . esc_url( get_permalink($parent) ) . '">' . esc_html( $parent->post_title ) . '</a></li> ' . esc_html( $delimiter ) . ' ';
			echo trim($before) . get_the_title() . sprintf( '%s', $after );

		} elseif ( is_page() && !$post->post_parent ) {
			echo trim($before) . get_the_title() . sprintf( '%s', $after );
			echo '<h2 class="active">'.get_the_title().'</h2>';

		} elseif ( is_page() && $post->post_parent ) {
			$parent_id  = $post->post_parent;
			$breadcrumbs = array();
			while ($parent_id) {
				$page = get_page($parent_id);
				$breadcrumbs[] = '<a href="' . esc_url( get_permalink($page->ID) ) . '">' . get_the_title($page->ID) . '</a></li>';
				$parent_id  = $page->post_parent;
			}
			$breadcrumbs = array_reverse($breadcrumbs);
			foreach ($breadcrumbs as $crumb) echo trim($crumb) . ' ' . esc_html( $delimiter ) . ' ';
			echo trim($before) . get_the_title() . sprintf( '%s', $after );
			echo '<h2 class="active">'.get_the_title().'</h2>';

		} elseif ( is_tag() ) {
			echo trim($before) . esc_html__('Posts tagged "', 'happychild') . single_tag_title('', false) . '"' . sprintf( '%s', $after );
			echo '<h2 class="active">'.esc_html__('Posts tagged', 'happychild').'</h2>';

		} elseif ( is_author() ) {
			global $author;
			$userdata = get_userdata($author);
			echo trim($before) . esc_html__('Articles posted by ', 'happychild') . esc_html( $userdata->display_name ) . sprintf( '%s', $after );
			echo '<h2 class="active">'.esc_html__('Posts Author', 'happychild').'</h2>';

		} elseif ( is_404() ) {
			echo trim($before) . esc_html__('Error 404', 'happychild') . sprintf( '%s', $after );
			echo '<h2 class="active">'.esc_html__('Error 404 ', 'happychild').'</h2>';
		}elseif( is_tax() ){
			echo trim($before) . esc_html__('Posts format', 'happychild'). sprintf( '%s', $after );
			echo '<h2 class="active">'.get_post_format().'</h2>';
		}else{
			echo trim($before) . esc_html__('Page detail', 'happychild'). sprintf( '%s', $after );
			echo '<h2 class="active">'.esc_html__('Page detail', 'happychild').'</h2>';
		}

		echo '</ol>';

	}
}


/**
 *
 */



/**
 *
 */
function happychild_display_footer_copyright(){
	$copyright_text =  happychild_fnc_theme_options('copyright_text', '');
	if(!empty($copyright_text)){
		echo do_shortcode($copyright_text);
	}else{
		$devby = '<a target="_blank" href="'.esc_url('http://themelexus.com').'">LexusThemes Team</a>';
		printf( esc_html__( 'Proudly powered by %s. Developed by %s', 'happychild' ), 'WordPress', $devby );   
	}
}

 
if(!function_exists('happychild_wpopal_categories_searchform')){
    function happychild_fnc_categories_searchform(){
        if( class_exists('WooCommerce') ){
		global $wpdb;
			$dropdown_args = array(
			    'show_counts'        => false,
			    'hierarchical'       => true,
			    'show_uncategorized' => 0
			);
		?>
		<form method="get" class="input-group search-category" action="<?php echo esc_url( home_url('/') ); ?>"><div class="input-group-addon search-category-container">
		  <div class="select">
		    <?php wc_product_dropdown_categories( $dropdown_args ); ?>
		  </div>
		</div>
		<input name="s" maxlength="60" class="form-control search-category-input" type="text" size="20" placeholder="<?php esc_html_e('What do you need...', 'happychild'); ?>"> 

		<div class="input-group-btn">
		    <label class="btn btn-link btn-search">
		      <span class="title-search hidden"><?php esc_html_e('Search', 'happychild') ?></span>
		      <input type="submit" class="fa searchsubmit" value="&#xf002;"/>
		    </label>
		    <input type="hidden" name="post_type" value="product"/>
		</div>
		</form>
		<?php
		}else{
			get_search_form();
		}
    }
}